@@ -3,8 +3,8 @@ package cmd
 import (
 	"net/http"
 
-	"github.com/cloudentity/oauth2c/internal/oauth2"
 	"github.com/cli/browser"
+	"github.com/cloudentity/oauth2c/internal/oauth2"
 )
 
 func (c *OAuth2Cmd) ImplicitGrantFlow(clientConfig oauth2.ClientConfig, serverConfig oauth2.ServerConfig, hc *http.Client) error {
@@ -25,10 +25,13 @@ func (c *OAuth2Cmd) ImplicitGrantFlow(clientConfig oauth2.ClientConfig, serverCo
 
 	LogRequest(authorizeRequest)
 
-	Logfln("\nOpen the following URL:\n\n%s\n", authorizeRequest.URL.String())
+	Logfln("\nGo to the following URL:\n\n%s", authorizeRequest.URL.String())
 
-	if err = browser.OpenURL(authorizeRequest.URL.String()); err != nil {
-		LogError(err)
+	if !clientConfig.NoBrowser {
+		Logfln("\nOpening browser...")
+		if err = browser.OpenURL(authorizeRequest.URL.String()); err != nil {
+			LogError(err)
+		}
 	}
 
 	Logln()
