@@ -10,6 +10,12 @@ import (
 	"github.com/pterm/pterm"
 )
 
+var (
+	version = "master"
+	commit  = "none"
+	date    = "unknown"
+)
+
 func init() {
 	c := make(chan os.Signal, 1)
 	signal.Notify(c, syscall.SIGINT, syscall.SIGTERM)
@@ -22,7 +28,7 @@ func init() {
 }
 
 func main() {
-	if err := cmd.NewOAuth2Cmd().Execute(); err != nil {
+	if err := cmd.NewOAuth2Cmd(version, commit, date).Execute(); err != nil {
 		fmt.Fprintln(os.Stderr, err)
 		os.Exit(1)
 	}
